@@ -21,13 +21,14 @@ def _get_package_path(package):
     return os.path.abspath(os.path.join(os.path.dirname(package.__file__), '..'))
 
 
-def install(version='6.0', packages=None):
+def install(version=None, packages=None):
     """Install COMPAS for Rhino.
 
     Parameters
     ----------
-    version : {'5.0', '6.0'}
+    version : {'5.0', '6.0'}, optional
         The version number of Rhino.
+        Default is ``'6.0'``.
     packages : list of str
         List of packages to install or None to use default package list.
 
@@ -43,6 +44,11 @@ def install(version='6.0', packages=None):
         $ python -m compas_rhino.install 6.0
 
     """
+    if version not in ('5.0', '6.0'):
+        version = '6.0'
+
+    if not packages:
+        packages = INSTALLABLE_PACKAGES
 
     print('Installing COMPAS packages to Rhino {0} IronPython lib:'.format(version))
 
@@ -105,19 +111,13 @@ def install(version='6.0', packages=None):
 
 if __name__ == "__main__":
 
-    import sys
+    import argparse
 
-    print('\nusage: python -m compas_rhino.install [version]\n')
-    print('  version       Rhino version (5.0 or 6.0)\n')
+    parser = argparse.ArgumentParser()
 
-    try:
-        version = sys.argv[1]
-    except IndexError:
-        version = '6.0'
-    else:
-        try:
-            version = str(version)
-        except Exception:
-            version = '6.0'
+    parser.add_argument('-v', '--version', choices=['5.0', '6.0'], default='5.0', help="The version of Rhino to install the packages in.")
+    parser.add_argument('-p', '--packages', nargs='+', help="The packages to install.")
 
-    install(version=version, packages=INSTALLABLE_PACKAGES)
+    args = parser.parse_args()
+
+    install(version=args.version, packages=args.packages)
